bread.contrib.workflows package
===============================

.. automodule:: bread.contrib.workflows
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib.workflows.management
   bread.contrib.workflows.models

Submodules
----------

bread.contrib.workflows.settings module
---------------------------------------

.. automodule:: bread.contrib.workflows.settings
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.workflows.views module
------------------------------------

.. automodule:: bread.contrib.workflows.views
   :members:
   :undoc-members:
   :show-inheritance:
